export declare type InternalNamePath = (string | number)[];
export declare type NamePath = string | number | InternalNamePath;
export interface FieldRule<FieldValue = any> {
    type?: 'string' | 'number' | 'boolean' | 'array' | 'object' | 'email' | 'url' | 'ip';
    required?: boolean;
    message?: string;
    length?: number;
    maxLength?: number;
    minLength?: number;
    max?: number;
    min?: number;
    match?: RegExp;
    /**
     * @zh 自定义校验
     * @param value
     * @param callback
     */
    validator?: (value: FieldValue | undefined, callback: (error?: string) => void) => void;
}
export declare const VALIDATE_STATUS: readonly ["success", "warning", "error", "validating"];
export declare type ValidateStatus = typeof VALIDATE_STATUS[number];
export declare const VALIDATE_TRIGGERS: readonly ["change", "input", "focus", "blur"];
export declare type ValidateTrigger = typeof VALIDATE_TRIGGERS[number];
export interface ValidatedError {
    label: string;
    field: string;
    value: any;
    type: string;
    isRequiredError: boolean;
    message: string;
}
export interface FormItemInfo {
    name: string;
    validate: () => Promise<any>;
}
export interface FormItemEventHandler {
    onChange?: (ev?: Event) => void;
    onInput?: (ev?: Event) => void;
    onBlur?: (ev?: Event) => void;
    onFocus?: (ev?: Event) => void;
}
