import { DataNode, DraggableOptions, TreeAction } from '../props';
import { TreeNode } from './tree-node';
export interface NodesMap {
    [x: string]: TreeNode;
}
export declare type TreeKey = string | number;
export declare type TreeStoreOptions = {
    data: DataNode[];
    draggableOptions?: DraggableOptions;
    emitChange: (data: DataNode[], action: TreeAction) => void;
};
export interface TreeStoreInitialize {
    data: DataNode[];
    draggableOptions?: DraggableOptions;
    emitChange?: (data: DataNode[], action: TreeAction) => void;
}
export declare class TreeStore implements TreeStoreOptions {
    nodesMap: Map<string | number, TreeNode>;
    nodeKey: string;
    root: TreeNode | null;
    data: DataNode[];
    selectedKey: string | number | undefined;
    checkedKeys: TreeKey[];
    expandedKeys: TreeKey[];
    dragNode: TreeNode | null;
    draggableOptions: DraggableOptions;
    emitChange: (data: DataNode[], action: TreeAction) => void;
    constructor(options?: TreeStoreOptions);
    initialize(options: TreeStoreInitialize): void;
    initialData(data: DataNode[]): void;
    registerNode(node: TreeNode): void;
    setCheckedKeys(checkedKeys: TreeKey[]): void;
    getCheckedKeys(): any[];
    observerNodeCheck(node: TreeNode, checked: boolean): void;
    setExpandedKeys(expandedKeys: TreeKey[]): void;
    expandedAll(): void;
    setSelectedKey(key: TreeKey): void;
    rename(key: TreeKey, value: string, close?: boolean): void;
    onNodeEdit(key: TreeKey, val: boolean): void;
    allowDrop(ev: DragEvent, dragNode: TreeNode | null, dropNode: TreeNode): boolean;
    getTreeNode(key: TreeKey): TreeNode | null;
    onDragstart(ev: DragEvent, node: TreeNode): void;
    onDragend(ev: DragEvent, node: TreeNode): void;
    onDrop(ev: DragEvent, node: TreeNode): void;
    sort(dragNode: TreeNode, dropNode: TreeNode, position: string): void;
    updateData(): boolean;
    static nodesToData(nodes: TreeNode[], data?: DataNode[]): DataNode[];
}
