import { PropType } from 'vue';
import { TreeNode } from './core/tree-node';
import { TreeKey } from './core/tree-store';
export interface DataNode {
    key?: string | number;
    label?: any;
    children?: DataNode[];
    checkable?: boolean;
    draggable?: boolean;
    droppable?: boolean;
    [x: string]: any;
}
export interface DraggableOptions {
    outside?: (() => boolean) | boolean;
    allowDrag?: (action: TreeAction) => boolean;
    allowDrop?: (action: TreeAction) => boolean;
    onDragstart?: (data: DataNode[], action: TreeAction) => void;
    onDrag?: (data: DataNode[], action: TreeAction) => void;
    onDragend?: (data: DataNode[], action: TreeAction) => void;
    onDrop?: (data: DataNode[], action: TreeAction) => void;
}
export interface RenameOptions {
    maxLength?: number;
}
export interface TreeAction {
    actionType?: 'move' | 'modify' | 'select' | 'check' | 'rename';
    ev?: Event | DragEvent;
    extra?: {
        drag?: {
            node?: TreeNode;
            data?: DataNode;
        };
        drop?: {
            node?: TreeNode;
            data?: DataNode;
        };
        node?: TreeNode;
        data?: DataNode;
        position?: string;
    } & {
        [x: string]: any;
    };
}
export declare const treeProps: () => {
    /**
     * @explan 组件名前缀
     */
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    /**
     * @explan 是否显示checkbox
     */
    checkable: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 是否允许拖拽
     */
    draggable: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 默认是否展开全部
     */
    defaultExpandAll: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 显示标识线
     */
    showLine: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 点击icon展开
     */
    expandedOnIcon: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 点击node时只展开
     */
    onlyExpandedTrueOnNode: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 启用rename功能
     */
    rename: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean; /**
         * @explan 渲染数据
         */
    };
    /**
     * @explan 渲染数据
     */
    treeData: {
        type: PropType<DataNode[]>;
        default: () => never[];
    };
    /**
     * @explan 勾选绑定值
     */
    checkedKeys: {
        type: PropType<TreeKey[]>;
        default: () => never[];
    };
    /**
     * @explan 展开绑定值
     */
    expandedKeys: {
        type: PropType<TreeKey[]>;
        default: () => undefined;
    };
    /**
     * @explan 拖拽配置项
     */
    draggableOptions: {
        type: PropType<DraggableOptions>;
        default: () => void;
    };
    /**
     * @explan rename配置项
     */
    renameOptions: {
        type: PropType<RenameOptions>;
        default: () => void;
    };
    /**
     * @explan 选中绑定值
     */
    selectedKey: {
        type: (NumberConstructor | StringConstructor)[];
        default: string;
    };
    /**
     * @explan node自定义数据
     */
    nodeExtraProps: {
        type: FunctionConstructor;
    };
};
export declare const treeNodeProps: () => {
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    data: {
        type: PropType<DataNode>;
    };
    renderNode: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
};
