import { PropType } from 'vue';
import { sizeTypes } from '../config-provider';
declare type RawValue = string | number;
export interface LabeledValue {
    key?: string;
    value: RawValue;
    label?: any;
}
export declare type SelectValue = RawValue | RawValue[] | LabeledValue | LabeledValue[] | undefined;
export interface BaseOptionType {
    disabled?: boolean;
    [name: string]: any;
}
export interface DefaultOptionType extends BaseOptionType {
    label?: any;
    value?: string | number | null;
    children?: Omit<DefaultOptionType, 'children'>[];
}
export declare type OptionType = DefaultOptionType;
export interface FieldNames {
    value?: string;
    label?: string;
    options?: string;
}
export declare type SelectHandler<ValueType = any, OptionType extends BaseOptionType = DefaultOptionType> = ((value: RawValueType | LabelInValueType, option: OptionType) => void) | ((value: ValueType, option: OptionType) => void);
export declare type SelectProps = {
    multiple: boolean;
    size: typeof sizeTypes;
    allowClear: boolean;
    defaultValue: string;
    value: SelectValue;
    options: OptionType[];
    fieldNames: FieldNames;
    dropdownMatchSelectWidth: boolean;
    dropdownZindex: number;
    dropdownVisible: boolean;
    dropdownClasses: string | string[];
    hideOnOtherArea: boolean;
};
export declare const selectProps: <ValueType = any, OptionType_1 extends BaseOptionType = DefaultOptionType>() => {
    /**
     * @explan 多选
     */
    multiple: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    /**
     * @explan 尺寸
     */
    size: import("vue-types").VueTypeDef<"small" | "middle" | "large"> & {
        default: "small" | "middle" | "large";
    };
    /**
     * @explan 允许一键清空
     */
    allowClear: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean;
    };
    /**
     * @explan 默认值
     */
    defaultValue: import("vue-types").VueTypeValidableDef<any>;
    /**
     * @explan 绑定值
     */
    value: {
        type: PropType<SelectValue>;
    };
    /**
     * @explan 可选项
     */
    options: {
        type: PropType<OptionType_1[]>;
    };
    disabled: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    /**
     * @explan 可选项字段配置
     */
    fieldNames: {
        type: PropType<FieldNames>;
    };
    /**
     * @explan 下拉菜单和选择器同宽
     */
    dropdownMatchSelectWidth: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @explan 下拉菜单的层级
     */
    dropdownZindex: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * @explan 下拉菜单是否展开
     */
    dropdownVisible: import("vue-types").VueTypeValidableDef<boolean>;
    /**
     * @explan 下拉菜单的类名
     */
    dropdownClasses: import("vue-types").VueTypeDef<string | (string | null | undefined)[] | null | undefined>;
    /**
     * @explan 点击其他地方关闭下拉菜单
     */
    hideOnOtherArea: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean;
    };
    /**
     * @explan 选中元素后关闭下拉框
     */
    hideOnSelect: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean;
    };
    /**
     * @explan placeholder
     */
    placeholder: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    /**
     * @explan 下拉菜单容器
     */
    getPopupContainer: {
        type: PropType<(...args: any) => any>;
    };
    /**
     * explan maxTagCount
     */
    maxTagCount: import("vue-types").VueTypeDef<string | number | null | undefined>;
    onSelect: PropType<SelectHandler<ValueType, OptionType_1>>;
    onChange: PropType<(value: ValueType, option: OptionType_1 | OptionType_1[]) => void>;
    onDropdownVisibleChange: PropType<(visible: Boolean) => void>;
};
export declare const selectorProps: () => {
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    open: import("vue-types").VueTypeValidableDef<boolean>;
    multiple: import("vue-types").VueTypeValidableDef<boolean>;
    values: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    allowClear: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    } & {
        default: boolean;
    };
    size: import("vue-types").VueTypeDef<"small" | "middle" | "large"> & {
        default: "small" | "middle" | "large";
    };
    placeholder: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    disabled: import("vue-types").VueTypeValidableDef<boolean>;
    options: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
};
export declare type RawValueType = string | number;
export declare type Key = string | number;
export declare type EventHandler = (...args: any[]) => void;
export interface DisplayValueType {
    key?: Key;
    value?: RawValueType;
    label?: any;
    disabled?: boolean;
    option?: BaseOptionType;
}
export interface InnerSelectorProps {
    prefixCls: string;
    placeholder?: any;
    disabled?: boolean;
    values: DisplayValueType[];
    searchValue: string;
    open: boolean;
    renderTitleNode?: () => JSX.Element;
}
export declare type OnInternalSelect = (value: RawValueType, info: {
    selected: boolean;
}) => void;
export interface LabelInValueType {
    label: any;
    value: RawValueType;
    /** @deprecated `key` is useless since it should always same as `value` */
    key?: Key;
}
export declare type DraftValueType = RawValueType | LabelInValueType | DisplayValueType | (RawValueType | LabelInValueType | DisplayValueType)[];
export {};
